{% load staticfiles %}<!DOCTYPE html>
<!--[if lt IE 7]>      <html {{ html_attr|safe }} class="no-js lt-ie9 lt-ie8 lt-ie7"> <![endif]-->
<!--[if IE 7]>         <html {{ html_attr|safe }} class="no-js lt-ie9 lt-ie8"> <![endif]-->
<!--[if IE 8]>         <html {{ html_attr|safe }} class="no-js lt-ie9"> <![endif]-->
<!--[if gt IE 8]><!--> <html {{ html_attr|safe }} class="no-js"> <!--<![endif]-->
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <title>{% block title %}{% endblock %}</title>
        <meta name="description" content="{% block description %}{% endblock %}">
        <meta name="viewport" content="width=device-width, initial-scale=1">

        <!-- Place favicon.ico and apple-touch-icon.png in the root directory -->

        <link rel="stylesheet" href="{% static "css/dh5bp/normalize.css" %}">
        <link rel="stylesheet" href="{% static "css/dh5bp/main.css" %}">
        <script src="{% static "js/dh5bp/vendor/modernizr-2.6.2.min.js" %}"></script>
        {% block head %}{% endblock %}
    </head>
    <body {{ body_attr|safe }}>
        <!--[if lt IE 7]>
            {% block outdated_message %}<p class="browsehappy">You are using an <strong>outdated</strong> browser. Please <a href="http://browsehappy.com/">upgrade your browser</a> to improve your experience.</p>{% endblock %}
        <![endif]-->

        <!-- Add your site or application content here -->
        {% block content %}<p>Hello world! This is HTML5 Boilerplate.</p>{% endblock %}

        <script src="//ajax.googleapis.com/ajax/libs/jquery/1.10.2/jquery.min.js"></script>
        <script>window.jQuery || document.write('<script src="{% static "js/dh5bp/vendor/jquery-1.10.2.min.js" %}"><\/script>')</script>
        <script src="{% static "js/dh5bp/plugins.js" %}"></script>
        {% block pre_main_script %}{% endblock %}
        <script src="{% if main_js %}{% static main_js %}{% else %}{% static "js/main.js" %}{% endif %}"></script>
        {% block post_main_script %}{% endblock %}

        <!-- Google Analytics: change {{ DH5BP_GA_CODE }} to be your site's ID. -->
        {% if DH5BP_GA_CODE %}<script>
            (function(b,o,i,l,e,r){b.GoogleAnalyticsObject=l;b[l]||(b[l]=
            function(){(b[l].q=b[l].q||[]).push(arguments)});b[l].l=+new Date;
            e=o.createElement(i);r=o.getElementsByTagName(i)[0];
            e.src='//www.google-analytics.com/analytics.js';
            r.parentNode.insertBefore(e,r)}(window,document,'script','ga'));
            ga('create','{{ DH5BP_GA_CODE }}');ga('send','pageview');
        </script>{% endif %}
    </body>
</html>
